@@ -13,7 +13,7 @@ var webui_i18n = {
     "GATEWAY TIMEOUT": "TEMPS DE PORTE",
 
     "request cancelled": "demande annulée",
-    "service unavailable": "Service indisponible",
+    "no connection": "pas de connection",
     "request failed": "demande échoué",
     "Failed to load all page contents !!": "Impossible de charger tout le contenu de la page !!",
     "Please reload page and try again.": "Veuillez recharger la page et réessayer.",
